WindowsHostRunnerPlatform class

Inheritance

Constructors

WindowsHostRunnerPlatform(Platform platform)
const

Properties

currentSourcePath → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
homePath → String
no setteroverride
pingSuccessRegex → RegExp?
no setteroverride
platform → Platform
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminalCommandRunner → List<String>
no setteroverride

Methods

addSshKeyToAgent({required String filePath}) → List<String>
inherited
commandRunner(List<String> commands) → List<String>
override
compressCommand({String compressedFileName = 'archive.tar.gz', String source = '.', bool lastCommand = false, List<String> exclude = const []}) → List<String>
This command is used to compress a folder
inherited
compressCurrentProjectCommand({required String compressedFileName}) → List<String>
This command is used to compress the current project
inherited
copySshKeyCommand({required String filePath, required bool ipv6, required String targetDevice}) → List<String>
override
deleteFile({required String target, bool lastCommand = false}) → List<String>
override
generateSshKeyCommand({required String filePath}) → List<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pingCommand({required bool ipv6, required String pingTarget}) → List<String>
override
scpCommand({required bool ipv6, required String source, required String dest, bool addHostToKnownHosts = false, bool lastCommand = false, String endCharacter = ';'}) → List<String>
inherited
sshCommand({required bool ipv6, required String sshTarget, required String command, bool addHostToKnownHosts = false, bool lastCommand = false, String endCharacter = ';'}) → List<String>
inherited
sshMultiCommand({required bool ipv6, required String sshTarget, required List<String> commands, bool addHostToKnownHosts = false, String endCharacter = ';'}) → List<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited