CustomDeviceBuilder class abstract

Implementers

Constructors

CustomDeviceBuilder({required FlutterSdkManager flutterSdkManager, required HostRunnerPlatform hostPlatform})
const
CustomDeviceBuilder.create({required FlutterEmbedder embedder, required FlutterSdkManager flutterSdkManager, required HostRunnerPlatform hostPlatform})
factory

Properties

flutterSdkManager → FlutterSdkManager
final
hashCode → int
The hash code for this object.
no setterinherited
hostPlatform → HostRunnerPlatform
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildDevice(DeviceConfigContext context) → Future<CustomDeviceConfig>
isContextValid(DeviceConfigContext context) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited