FlutterLinuxEmbedderProvider class

Inheritance

Constructors

FlutterLinuxEmbedderProvider({required DeviceConfigContext context, required RemoteControllerService remoteControllerService})
const

Properties

context → DeviceConfigContext
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
remoteControllerService → RemoteControllerService
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provideEmbedderPath() → Future<String>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited