Spinner class

Constructors

Spinner({required String inProgressMessage, String doneMessage = 'Done!', String failedMessage = 'Failed!'})

Properties

doneMessage → String
final
failedMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
inProgressMessage → String
final
progress ↔ Progress?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

done() → void
failed() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited