DeviceConfigContext class

Constructors

DeviceConfigContext({String? id, String? label, InternetAddress? targetIp, String? username, bool remoteHasSshConnection = false, String? appExecuterPath, FlutterEmbedder? embedder})
const

Properties

appExecuterPath → String?
final
embedder → FlutterEmbedder?
final
formattedLabel → String
no setter
formattedLoopbackIp → String?
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → String?
final
ipv6 → bool?
no setter
label → String?
final
loopbackIp → InternetAddress?
no setter
remoteHasSshConnection → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkName → String?
no setter
sshTarget → String?
no setter
targetIp → InternetAddress?
final
username → String?
final

Methods

copyWith({String? id, String? label, InternetAddress? targetIp, String? username, bool? remoteHasSshConnection, String? appExecuterPath, FlutterEmbedder? embedder}) → DeviceConfigContext
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const DeviceConfigContext